@@ -25,6 +25,9 @@ class SequoiaGenerator(ConfigGenerator):
 
     CONFIG_NAME = 'sequoia'
 
+    force_on_group = []
+    force_on_sign = []
+
     # sequoia display name to c-p name, taken from sequoia_openpgp/types/mod.rs
     hash_backwards_map = {
         'md5': 'MD5',
@@ -143,10 +146,14 @@ class SequoiaGenerator(ConfigGenerator):
         # groups
         for seq_name, group in cls.asymmetric_group_backwards_map.items():
             v = 'always' if group in p['group'] else 'never'
+            if group in cls.force_on_group:
+                v = 'always'
             cfg += f'{seq_name} = "{v}"\n'
         # sign
         for seq_name, sign in cls.asymmetric_sign_backwards_map.items():
             v = 'always' if sign in p['sign'] else 'never'
+            if sign in cls.force_on_sign:
+                v = 'always'
             cfg += f'{seq_name} = "{v}"\n'
         # always disabled
         for seq_name in cls.asymmetric_always_disabled:
@@ -215,6 +222,10 @@ class SequoiaGenerator(ConfigGenerator):
 class RPMSequoiaGenerator(SequoiaGenerator):
     CONFIG_NAME = 'rpm-sequoia'
 
+    # RHEL-112392 hack: some algorithms have to be force-enabled
+    force_on_group = ['MLKEM768-X25519', 'MLKEM1024-X448']
+    force_on_sign = ['MLDSA65-ED25519', 'MLDSA87-ED448']
+
     @classmethod
     def generate_config(cls, unscoped_policy):
         return cls._generate_config(unscoped_policy.scoped({'rpm',
